==> nef_pipelines-0.1.112.tar.gz: nef_pipelines-0.1.112/src/nef_pipelines/tests/frames/test_list.py <==
from pathlib import Path

import typer

from nef_pipelines.lib.test_lib import (
    assert_lines_match,
    path_in_test_data,
    run_and_report,
)
from nef_pipelines.tools.frames.list import list

app = typer.Typer()
app.command()(list)


# noinspection PyUnusedLocal
def test_frame_basic():

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, ["--in", path])

    EXPECTED = """\
        nef_nmr_meta_data  nef_molecular_system
    """

    assert_lines_match(EXPECTED, result.stdout)


# noinspection PyUnusedLocal
def test_frame_file_first():

    path = path_in_test_data(__file__, "frames.nef")

    result = run_and_report(app, [path])

    EXPECTED = """\
        nef_nmr_meta_data  nef_molecular_system
    """

    assert_lines_match(EXPECTED, result.stdout)


# noinspection PyUnusedLocal
def test_frame_file_first_and_select():

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, [path, "meta_data"])

    EXPECTED = """\
        nef_nmr_meta_data
    """

    assert_lines_match(EXPECTED, result.stdout)


def test_frame_no_file():

    path = Path("NO_SUCH_FILE")
    run_and_report(app, [path], expected_exit_code=1)


def test_frame_basic_verbose():

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, ["--in", path, "--verbose"])

    EXPECTED_VERBOSE = """
        entry test
            lines: 48 frames: 2 checksum: d6235a487cbdb33cb1ed5d2f5f3f2635 [md5]
        1. nef_nmr_meta_data
            category: nef_nmr_meta_data
            loops: 1 [lengths: 19]
            loop names: nef_program_script
            is nef frame: True
        2. nef_molecular_system
            category: nef_molecular_system
            loops: 1 [lengths: 13]
            loop names: nef_sequence
            is nef frame: True

    """

    assert_lines_match(EXPECTED_VERBOSE, result.stdout)

==> nef_pipelines-0.1.118.tar.gz: nef_pipelines-0.1.118/src/nef_pipelines/tests/frames/test_list.py <==
from pathlib import Path

import typer

from nef_pipelines.lib.test_lib import (
    assert_lines_match,
    path_in_test_data,
    run_and_report,
)
from nef_pipelines.tools.frames.list import list

app = typer.Typer()
app.command()(list)


# noinspection PyUnusedLocal
def test_frame_basic():

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, ["--in", path])

    EXPECTED = """\
        nef_nmr_meta_data  nef_molecular_system
    """

    assert_lines_match(EXPECTED, result.stdout)


# noinspection PyUnusedLocal
def test_frame_file_first():

    path = path_in_test_data(__file__, "frames.nef")

    result = run_and_report(app, [path])

    EXPECTED = """\
        nef_nmr_meta_data  nef_molecular_system
    """

    assert_lines_match(EXPECTED, result.stdout)


# noinspection PyUnusedLocal
def test_frame_file_first_and_select():

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, [path, "meta_data"])

    EXPECTED = """\
        nef_nmr_meta_data
    """

    assert_lines_match(EXPECTED, result.stdout)


def test_frame_no_file():

    path = Path("NO_SUCH_FILE")
    run_and_report(app, [path], expected_exit_code=1)


def test_frame_basic_verbose():

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, ["--in", path, "--verbose"])

    EXPECTED_VERBOSE = """
        entry test
            lines: 48 frames: 2 checksum: d6235a487cbdb33cb1ed5d2f5f3f2635 [md5]
        1. nef_nmr_meta_data
            category: nef_nmr_meta_data
            loops: 1 [lengths: 19]
            loop names: nef_program_script
            is nef frame: True
        2. nef_molecular_system
            category: nef_molecular_system
            loops: 1 [lengths: 13]
            loop names: nef_sequence
            is nef frame: True

    """

    assert_lines_match(EXPECTED_VERBOSE, result.stdout)


def test_frame_no_matching_frames():
    """Test that frames list doesn't crash when no frames match the filter."""

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, ["--in", path, "non_existent_frame"])

    EXPECTED_NO_FRAMES = """"""

    assert_lines_match(EXPECTED_NO_FRAMES, result.stdout)


def test_frame_empty_stdin_shows_help():
    """Test that frames list shows help and error message when no stdin input is available."""

    # Run without --in and without stdin input (should trigger NEFPLSLIOEmptyStdinException)
    result = run_and_report(app, [], expected_exit_code=0)

    # Check that help text is displayed
    assert "Usage:" in result.stdout
    assert "list [OPTIONS] [FILTERS]" in result.stdout

    # Check that the error message is displayed
    assert "No input NEF entry from stdin or the command line..." in result.stdout


def test_frame_with_no_filters_doesnt_fail():
    """Test that frames list doesn't crash when no no filters are applied."""

    path = path_in_test_data(__file__, "frames.nef")
    result = run_and_report(app, ["--in", path])

    EXPECTED_NO_FRAMES = "nef_nmr_meta_data nef_molecular_system"

    assert_lines_match(EXPECTED_NO_FRAMES, result.stdout)
